"""
This file is part of nucypher.

nucypher is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

nucypher is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
"""

from pathlib import Path
from constant_sorrow.constants import (NO_BLOCKCHAIN_CONNECTION)

# TODO: Move to constants.py?
BASE_DIRECTORY = Path(__file__).parent
CONTRACT_REGISTRY_BASE = BASE_DIRECTORY / "contract_registry"

NO_BLOCKCHAIN_CONNECTION.bool_value(False)
